aboutsummaryrefslogtreecommitdiff
path: root/include/sway
diff options
context:
space:
mode:
authorDrew DeVault <sir@cmpwn.com>2018-04-06 15:03:05 -0400
committerDrew DeVault <sir@cmpwn.com>2018-04-06 15:38:37 -0400
commit764489e73760534d49760af123cae46109564e86 (patch)
tree243104969dc80855d313faf5a0d360dd5508dc52 /include/sway
parentd447460c0153a76a0bc484bb9866cef658b3102f (diff)
Break everything^W^WUse wlr_box for sway_container
Diffstat (limited to 'include/sway')
-rw-r--r--include/sway/tree/container.h10
-rw-r--r--include/sway/tree/layout.h3
2 files changed, 5 insertions, 8 deletions
diff --git a/include/sway/tree/layout.h b/include/sway/tree/layout.h
index fc5ce21f..b2b98ee4 100644
--- a/include/sway/tree/layout.h
+++ b/include/sway/tree/layout.h
@@ -61,8 +61,7 @@ enum sway_container_layout container_get_default_layout(
void container_sort_workspaces(struct sway_container *output);
-void arrange_windows(struct sway_container *container,
- double width, double height);
+void arrange_windows(struct sway_container *container, int width, int height);
struct sway_container *container_get_in_direction(struct sway_container
*container, struct sway_seat *seat, enum movement_direction dir);
diff --git a/include/sway/tree/container.h b/include/sway/tree/container.h
index 4c60530f..e7a071be 100644
--- a/include/sway/tree/container.h
+++ b/include/sway/tree/container.h
@@ -68,12 +68,10 @@ struct sway_container {
enum sway_container_layout prev_layout;
enum sway_container_layout workspace_layout;
- // For C_ROOT, this has no meaning
- // For C_OUTPUT, this is the output position in layout coordinates
- // For other types, this is the position in output-local coordinates
- double x, y;
- // does not include borders or gaps.
- double width, height;
+ // For C_ROOT, this is the extents of the whole layout box.
+ // For C_OUTPUT, this is the output position in layout coordinates.
+ // For other types, this is the position in output-local coordinates.
+ struct wlr_box box;
list_t *children;